package main

import (
	"oc-auth/conf"
	_ "oc-auth/routers"

	"github.com/beego/beego/logs"
	beego "github.com/beego/beego/v2/server/web"
	"github.com/goraz/onion"
)

const defaultConfigFile = "/etc/oc/auth.json"
const localConfigFile = "./auth.json"

func main() {
	log := logs.NewLogger(10000)
	log.SetLogger("console")

	configFile := ""
	var o *onion.Onion
	l3 := onion.NewEnvLayerPrefix("_", "OCAUTH_")
	l2, err := onion.NewFileLayer(defaultConfigFile, nil)
	if err == nil {
		logs.Info("Config file found : " + defaultConfigFile)
		configFile = defaultConfigFile
	}
	l1, err := onion.NewFileLayer(localConfigFile, nil)
	if err == nil {
		logs.Info("Local config file found " + localConfigFile + ", overriding default file")
		configFile = localConfigFile
	}
	if configFile == "" {
		logs.Info("No config file found, using env")
		o = onion.New(l3)
	} else if l1 == nil && l2 == nil {
		o = onion.New(l1, l2, l3)
	} else if l1 == nil {
		o = onion.New(l2, l3)
	} else if l2 == nil {
		o = onion.New(l1, l3)
	}

	conf.GetConfig().NatsUrl = o.GetStringDefault("natsurl", "http://localhost:4080")
	conf.GetConfig().NatsLogin = o.GetStringDefault("natslogin", "admin")
	conf.GetConfig().NatsPassword = o.GetStringDefault("natspassword", "admin")
	conf.GetConfig().OidcUrl = o.GetStringDefault("oidcurl", "admin")

	// Normal beego init
	//if beego.BConfig.RunMode == "dev" {
	beego.BConfig.WebConfig.DirectoryIndex = true
	beego.BConfig.WebConfig.StaticDir["/swagger"] = "swagger"
	//}
	beego.Run()
}
